<?php

namespace Drupal\smsgateway_msg91\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Plugin\Action\ConfigurableActionBase;
use Drupal\Core\TypedData\TraversableTypedDataInterface;
use Drupal\eca\Plugin\DataType\DataTransferObject;

/**
 * Load the currently logged in user into the token environment.
 *
 * @Action(
 *   id = "smsgateway_msg91_load_selected_template",
 *   label = @Translation("Current template: load"),
 *   description = @Translation("Load the current user and store it as a token.")
 * )
 */
class LoadCurrentTemplate extends ConfigurableActionBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return ['token_name' => 'template',
            'smsTemplate'=>'',        
            'mobile_number'=>'',
            'template_variables'=>''] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $options = $this->getSmsTemplateOptions();
    
    $form['smsTemplate'] = [
         '#type' => 'select',
         '#title' => t('SMS Template'),
         '#description' => t('This is the SMS template selection to send SMS'),
         '#default_value' => $this->configuration['smsTemplate'],
         '#options' => $options,
         '#required' => TRUE,
     ];

    $form['token_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name of token'),
      '#description' => $this->t('The loaded current template will be stored into this token.'),
      '#default_value' => $this->configuration['token_name'],
      '#eca_token_reference' => TRUE,
    ];

    //sms-field name
    $form['mobile_number'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Mobile Number'),
      '#description' => $this->t('Add Mobile Number'),
      '#default_value' => $this->configuration['mobile_number'],
      //'#required' => TRUE,
    ];
     $form['template_variables'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Template variables'),
      '#description' => $this->t('Add Template Variable with comma(,) seprated'),
      '#default_value' => $this->configuration['template_variables'],
     // '#required' => TRUE,
    ];
    
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['smsTemplate'] = $form_state->getValue('smsTemplate');
    $this->configuration['token_name'] = $form_state->getValue('token_name');   
    $this->configuration['mobile_number'] = $form_state->getValue('mobile_number');
    $this->configuration['template_variables'] = $form_state->getValue('template_variables');
    parent::submitConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function execute(): void {
      
      $token_services = \Drupal::service('eca.token_services');
      $this->configuration['token_name'];
      $this->configuration['smsTemplate'];
      
      $template_variable = $this->configuration['template_variables'];
      $data= $this->getTemplateVariables($template_variable);
      $mobile_number = trim((string) $this->configuration['mobile_number']);
      $mobileArr = $token_services->getTokenData($mobile_number);
      $data['mobiles']= $mobileArr->value;
      $json = json_encode($data);
      //$token_data = $token_services->getTokenData($message_variable);  

    if ($template = $this->configuration['smsTemplate']) {
      $token_name = trim($this->configuration['token_name'] ?? '');
      if ($token_name === '') {
        $token_name = 'template';
      }
      
      $this->tokenServices->addTokenData($token_name, $template);
      $this->tokenServices->addTokenData('template_var', DataTransferObject::create($data));
    }
  }
  
/**
 * Get SMS template options.
 *
 * @return array
 *   An associative array of SMS template options.
 */
    protected function getSmsTemplateOptions() {
        $database = \Drupal::database();
        $query = $database->query("SELECT id,templateName FROM {smsgateway_msg91_email_templates}  WHERE status=1");
        $result = $query->fetchAll();
        $options=[];
        if(!empty($result)){
            foreach ($result as $data) {
                $options[$data->id] = $data->templateName;
            }
        }
        return $options;
    }
    
    /**
     * getTemplateVariables
     * @param type $param
     * @return type
     */
    protected function getTemplateVariables($param) {
        $token_services = \Drupal::service('eca.token_services');

        if(empty($param)){
            return;
        }
        $arrParam = explode(',', $param);
        $data=[];    
        $no = 1;
        foreach ($arrParam as $val) {
            $dataVal = $token_services->getTokenData($val);
            $data['var' . $no] = $dataVal->value;
            $no++;
        }
        return $data;
    }

}
